@@ -11,9 +11,11 @@
 # @summary: Mac Installation script of QSTK
 #
 
+# Macports Python has already been installed.
+
 echo "Installing dependency - GIT"
 sudo port install git-core +svn
-sudo port install python27
+sudo port install py27-distribute
 echo "Installing dependencies - Numpy Scipy matplotlib"
 sudo port install py27-numpy
 sudo port install py27-scipy
@@ -21,14 +23,11 @@ sudo port install py27-matplotlib
 echo "Installing dependencies - developer tools"
 sudo port install py27-dateutil
 echo "Installing dependencies - scikits"
-sudo easy_install -U scikits-learn
+sudo easy_install -U scikit-learn
 echo "Installing dependencies - pandas"
 sudo easy_install pandas==0.7.3
-echo "Installing dependencies - Docs/Distribute"
+echo "Installing dependencies - Docs"
 sudo port install py27-epydoc
-sudo port install py27-distribute
 echo "Installing dependencies - PYQT4"
 sudo port install py27-pyqt4
-echo "Installing dependencies - CVXOPT"
-sudo port install py27-cvxopt
 echo "Installing dependencies complete"
